ByteLengthQueuingStrategy class

Implemented types
Available extensions
Annotations

Constructors

ByteLengthQueuingStrategy(IInline40 options)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
highWaterMark num

Available on ByteLengthQueuingStrategy, provided by the ByteLengthQueuingStrategy$Typings extension

getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size num Function(ArrayBufferView)

Available on ByteLengthQueuingStrategy, provided by the ByteLengthQueuingStrategy$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited