CountQueuingStrategy class

This Streams API interface provides a built-in byte length queuing strategy that can be used when constructing streams.

Implemented types
Available extensions
Annotations

Constructors

CountQueuingStrategy(IInline38 options)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
highWaterMark num

Available on CountQueuingStrategy, provided by the CountQueuingStrategy$Typings extension

getter/setter pair
highWaterMark num?

Available on QueuingStrategy<T>, provided by the QueuingStrategy$Typings extension

getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size num Function([dynamic])

Available on CountQueuingStrategy, provided by the CountQueuingStrategy$Typings extension

getter/setter pair
size QueuingStrategySizeCallback<T>?

Available on QueuingStrategy<T>, provided by the QueuingStrategy$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited