CryptoKey class

The CryptoKey dictionary of the Web Crypto API represents a cryptographic key.

Available extensions
Annotations

Constructors

CryptoKey()
factory

Properties

algorithm → KeyAlgorithm

Available on CryptoKey, provided by the CryptoKey$Typings extension

no setter
extractable → bool

Available on CryptoKey, provided by the CryptoKey$Typings extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → KeyType

Available on CryptoKey, provided by the CryptoKey$Typings extension

no setter
usages → List<KeyUsage>

Available on CryptoKey, provided by the CryptoKey$Typings extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited