FormData class

Provides a way to easily construct a set of key/value pairs representing form fields and their values, which can then be easily sent using the XMLHttpRequest.send() method. It uses the same format a form would use if the encoding type were set to "multipart/form-data".

Implemented types
Available extensions
Annotations

Constructors

FormData()
factory

Properties

append ↔ void Function(String, Object, [String?])

Available on FormData, provided by the FormData$Typings extension

getter/setter pair
delete ↔ void Function(String)

Available on FormData, provided by the FormData$Typings extension

getter/setter pair
get ↔ Object? Function(String)

Available on FormData, provided by the FormData$Typings extension

getter/setter pair
getAll ↔ List<Object> Function(String)

Available on FormData, provided by the FormData$Typings extension

getter/setter pair
has ↔ bool Function(String)

Available on FormData, provided by the FormData$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
set ↔ void Function(String, Object, [String?])

Available on FormData, provided by the FormData$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited