Memory class

The WebAssembly.Memory object is a resizable ArrayBuffer or SharedArrayBuffer that holds the raw bytes of memory accessed by a WebAssembly Instance.

A memory created by JavaScript or in WebAssembly code will be accessible and mutable from both JavaScript and WebAssembly.

MDN

Available extensions
Annotations

Constructors

Memory(MemoryDescriptor descriptor)
factory

Properties

buffer Object

Available on Memory, provided by the Memory$Typings extension

An accessor property that returns the buffer contained in the memory.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

grow(num delta) num

Available on Memory, provided by the Memory$Typings extension

Increases the size of the memory instance by a specified number of WebAssembly pages (each one is 64KB in size).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited