NotFound class

Raised when the underlying operating system indicates that the file was not found.

Implemented types
Available extensions
Annotations

Constructors

NotFound()

Properties

cause Object?

Available on Error, provided by the Error$Typings extension

getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
message String

Available on Error, provided by the Error$Typings extension

getter/setter pair
name String

Available on Error, provided by the Error$Typings extension

getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stack String?

Available on Error, provided by the Error$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited