Performance class

Deno supports User Timing Level 3 which is not widely supported yet in other runtimes.

Check out the Performance API documentation on MDN for further information about how to use the API.

Available extensions
Annotations

Constructors

Performance()
factory

Properties

clearMarks ↔ void Function([String?])

Available on Performance, provided by the Performance$Typings extension

getter/setter pair
clearMeasures ↔ void Function([String?])

Available on Performance, provided by the Performance$Typings extension

getter/setter pair
getEntries List Function()

Available on Performance, provided by the Performance$Typings extension

getter/setter pair
getEntriesByName List Function(String, [String?])

Available on Performance, provided by the Performance$Typings extension

getter/setter pair
getEntriesByType List Function(String)

Available on Performance, provided by the Performance$Typings extension

getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mark → ({PerformanceMark Function(String markName, [PerformanceMarkOptions? options]) $1, PerformanceMark Function(String markName, [PerformanceMarkOptions? options]) $2})

Available on Performance, provided by the Performance$Typings extension

Overload accessor: $1, $2
no setter
measure → ({PerformanceMeasure Function(String measureName, [PerformanceMeasureOptions? options]) $1, PerformanceMeasure Function(String measureName, [PerformanceMeasureOptions? options]) $2, PerformanceMeasure Function(String measureName, [String? startMark, String? endMark]) $3})

Available on Performance, provided by the Performance$Typings extension

Overload accessor: $1, $2, $3
no setter
now num Function()

Available on Performance, provided by the Performance$Typings extension

getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeOrigin num

Available on Performance, provided by the Performance$Typings extension

Returns a timestamp representing the start of the performance measurement.
no setter
toJSON ↔ dynamic Function()

Available on Performance, provided by the Performance$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited