PerformanceEntry class

Encapsulates a single performance metric that is part of the performance timeline. A performance entry can be directly created by making a performance mark or measure (for example by calling the .mark() method) at an explicit point in an application.

Implementers
Available extensions
Annotations

Constructors

PerformanceEntry()
factory

Properties

duration num

Available on PerformanceEntry, provided by the PerformanceEntry$Typings extension

no setter
entryType String

Available on PerformanceEntry, provided by the PerformanceEntry$Typings extension

no setter
hashCode int
The hash code for this object.
no setterinherited
name String

Available on PerformanceEntry, provided by the PerformanceEntry$Typings extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime num

Available on PerformanceEntry, provided by the PerformanceEntry$Typings extension

no setter
toJSON ↔ dynamic Function()

Available on PerformanceEntry, provided by the PerformanceEntry$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited