ReadableStreamDefaultReadDoneResult class

Available extensions
Annotations

Constructors

ReadableStreamDefaultReadDoneResult({bool? done, dynamic value})
factory

Properties

done ↔ bool

Available on ReadableStreamDefaultReadDoneResult, provided by the ReadableStreamDefaultReadDoneResult$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ dynamic

Available on ReadableStreamDefaultReadDoneResult, provided by the ReadableStreamDefaultReadDoneResult$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited