Table class

The WebAssembly.Table() object is a JavaScript wrapper object — an array-like structure representing a WebAssembly Table, which stores function references. A table created by JavaScript or in WebAssembly code will be accessible and mutable from both JavaScript and WebAssembly.

MDN

Available extensions
Annotations

Constructors

Table(TableDescriptor descriptor)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
length num

Available on Table, provided by the Table$Typings extension

Returns the length of the table, i.e. the number of elements.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(num index) Function?

Available on Table, provided by the Table$Typings extension

Accessor function — gets the element stored at a given index.
grow(num delta) num

Available on Table, provided by the Table$Typings extension

Increases the size of the Table instance by a specified number of elements.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(num index, [Function? value]) → void

Available on Table, provided by the Table$Typings extension

Sets an element stored at a given index to a given value.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited