UnderlyingByteSource class

Available extensions
Annotations

Properties

autoAllocateChunkSize ↔ num?

Available on UnderlyingByteSource, provided by the UnderlyingByteSource$Typings extension

getter/setter pair
cancel ↔ ReadableStreamErrorCallback?

Available on UnderlyingByteSource, provided by the UnderlyingByteSource$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pull ↔ ReadableByteStreamControllerCallback?

Available on UnderlyingByteSource, provided by the UnderlyingByteSource$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start ↔ ReadableByteStreamControllerCallback?

Available on UnderlyingByteSource, provided by the UnderlyingByteSource$Typings extension

getter/setter pair
type ↔ String

Available on UnderlyingByteSource, provided by the UnderlyingByteSource$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited