WebSocketUpgrade class

The object that is returned from a {@linkcode Deno.upgradeWebSocket} request.

Available extensions
Annotations

Constructors

WebSocketUpgrade({Response? response, WebSocket? socket})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
response ↔ Response

Available on WebSocketUpgrade, provided by the WebSocketUpgrade$Typings extension

The response object that represents the HTTP response to the client, which should be used to the {@linkcode RequestEvent} .respondWith() for the upgrade to be successful.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
socket ↔ WebSocket

Available on WebSocketUpgrade, provided by the WebSocketUpgrade$Typings extension

The {@linkcode WebSocket} interface to communicate to the client via a web socket.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited