CircularLayout$Typings extension

on

Properties

actualCenter ↔ Point

Available on CircularLayout, provided by the CircularLayout$Typings extension

This read-only property is the coordinates of the center of the laid-out ellipse immediately after the layout.
getter/setter pair
actualSpacing ↔ num

Available on CircularLayout, provided by the CircularLayout$Typings extension

This read-only property is the effective spacing that may have been calculated by the layout.
getter/setter pair
actualXRadius ↔ num

Available on CircularLayout, provided by the CircularLayout$Typings extension

This read-only property is the effective X radius that may have been calculated by the layout.
getter/setter pair
actualYRadius ↔ num

Available on CircularLayout, provided by the CircularLayout$Typings extension

This read-only property is the effective Y radius that may have been calculated by the layout.
getter/setter pair
arrangement ↔ EnumValue

Available on CircularLayout, provided by the CircularLayout$Typings extension

Gets or sets how the nodes are spaced. If #arrangement === CircularLayout.Packed, the specified #radius will be ignored.
getter/setter pair
aspectRatio ↔ num

Available on CircularLayout, provided by the CircularLayout$Typings extension

Gets or sets the ratio of the arrangement's height to its width (1 for a circle, >1 for a vertically elongated ellipse).
getter/setter pair
comparer ↔ num Function(CircularVertex, CircularVertex)

Available on CircularLayout, provided by the CircularLayout$Typings extension

Gets or sets the comparer which sorts the data when #sorting is set to CircularLayout.Ascending or CircularLayout.Descending.
getter/setter pair
direction ↔ EnumValue

Available on CircularLayout, provided by the CircularLayout$Typings extension

Gets or sets whether the nodes are arranged clockwise or counterclockwise.
getter/setter pair
nodeDiameterFormula ↔ EnumValue

Available on CircularLayout, provided by the CircularLayout$Typings extension

Specifies how the diameter of nodes will be calculated. When a node is not circular, it is not clear what its diameter is.
getter/setter pair
radius ↔ num

Available on CircularLayout, provided by the CircularLayout$Typings extension

Gets or sets the horizontal radius of the elliptical arrangement.
getter/setter pair
sorting ↔ EnumValue

Available on CircularLayout, provided by the CircularLayout$Typings extension

Gets or sets if and how the nodes are sorted.
getter/setter pair
spacing ↔ num

Available on CircularLayout, provided by the CircularLayout$Typings extension

Gets or sets the distance between nodes (if #radius is NaN) or the minimum distance between nodes (if #radius is a number).
getter/setter pair
startAngle ↔ num

Available on CircularLayout, provided by the CircularLayout$Typings extension

Gets or sets the angle (in degrees, clockwise from the positive side of the X axis) of the first element.
getter/setter pair
sweepAngle ↔ num

Available on CircularLayout, provided by the CircularLayout$Typings extension

Gets or sets the absolute angle (in degrees) between the first and last node.
getter/setter pair

Methods

commitLayout() → void

Available on CircularLayout, provided by the CircularLayout$Typings extension

Position each Node according to the Vertex position, and then position the Links.

Available on CircularLayout, provided by the CircularLayout$Typings extension

Commit the position and routing of all edge links. This is called by #commitLayout. This is only called if Layout#isRouting is true. Please read the Introduction page on Extensions for how to override methods and how to call this base method.
commitNodes() → void

Available on CircularLayout, provided by the CircularLayout$Typings extension

Commit the position of all vertex nodes. Please read the Introduction page on Extensions for how to override methods and how to call this base method.
createNetwork() → CircularNetwork

Available on CircularLayout, provided by the CircularLayout$Typings extension

Create a new LayoutNetwork of CircularVertexes and CircularEdges. @return {CircularNetwork} a new LayoutNetwork.
doLayout(Object coll) → void

Available on CircularLayout, provided by the CircularLayout$Typings extension

Assign the positions of the vertexes in the network. @param {Diagram|Group|Iterable.