ISurface class

(undocumented) interface used for both the SVGSurface and the CanvasSurface, which are undocumented classes.

Available extensions
Annotations

Constructors

ISurface({Element? domElement, IContext? context, num? width, num? height, Document? ownerDocument, void elementFinished(GraphObject, SVGElement)?, CSSStyleDeclaration? style, bool resize(num, num, num, num)?, DOMRect getBoundingClientRect()?, void focus()?, void dispose()?})
factory

Properties

context ↔ IContext

Available on ISurface, provided by the ISurface$Typings extension

getter/setter pair
dispose ↔ void Function()

Available on ISurface, provided by the ISurface$Typings extension

getter/setter pair
domElement ↔ Element

Available on ISurface, provided by the ISurface$Typings extension

getter/setter pair
elementFinished ↔ void Function(GraphObject, SVGElement)?

Available on ISurface, provided by the ISurface$Typings extension

getter/setter pair
focus ↔ void Function()

Available on ISurface, provided by the ISurface$Typings extension

getter/setter pair
getBoundingClientRect ↔ DOMRect Function()

Available on ISurface, provided by the ISurface$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ num

Available on ISurface, provided by the ISurface$Typings extension

getter/setter pair
ownerDocument ↔ Document

Available on ISurface, provided by the ISurface$Typings extension

getter/setter pair
resize ↔ bool Function(num, num, num, num)

Available on ISurface, provided by the ISurface$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style ↔ CSSStyleDeclaration

Available on ISurface, provided by the ISurface$Typings extension

getter/setter pair
width ↔ num

Available on ISurface, provided by the ISurface$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited