Iterator$Typings<T> extension

on

Properties

all ↔ bool Function(bool (T))

Available on Iterator<T>, provided by the Iterator$Typings extension

getter/setter pair
any ↔ bool Function(bool (T))

Available on Iterator<T>, provided by the Iterator$Typings extension

getter/setter pair
count → num

Available on Iterator<T>, provided by the Iterator$Typings extension

This read-only property is the total number of items in the iterated collection.
no setter
each ↔ void Function(void (T))

Available on Iterator<T>, provided by the Iterator$Typings extension

getter/setter pair
filter ↔ Iterator<T> Function(bool (T))

Available on Iterator<T>, provided by the Iterator$Typings extension

getter/setter pair
first ↔ T? Function()

Available on Iterator<T>, provided by the Iterator$Typings extension

getter/setter pair
hasNext ↔ bool Function()

Available on Iterator<T>, provided by the Iterator$Typings extension

getter/setter pair
iterator ↔ Iterator<T>

Available on Iterator<T>, provided by the Iterator$Typings extension

Returns itself, which is convenient for code that expects an Iterable instead of an Iterator. @return {Iterator.
getter/setter pair
key → dynamic

Available on Iterator<T>, provided by the Iterator$Typings extension

Gets the current index to the item in the collection, assuming #next has just returned true.
no setter
map ↔ Iterator<S> Function<S>(S (T))

Available on Iterator<T>, provided by the Iterator$Typings extension

getter/setter pair
next ↔ bool Function()

Available on Iterator<T>, provided by the Iterator$Typings extension

getter/setter pair
reset ↔ void Function()

Available on Iterator<T>, provided by the Iterator$Typings extension

getter/setter pair
value → T

Available on Iterator<T>, provided by the Iterator$Typings extension

Gets the current item in the collection, assuming #next has just returned true.
no setter