CancellationError class

An error type that should be used to signal cancellation of an operation.

This type can be used in response to a {@link CancellationTokencancellation token} being cancelled or when an operation is being cancelled by the executor of that operation.

Implemented types
Available extensions
Annotations

Constructors

CancellationError()
factory

Properties

cause Object?

Available on Error, provided by the Error$Typings extension

getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
message String

Available on Error, provided by the Error$Typings extension

getter/setter pair
name String

Available on Error, provided by the Error$Typings extension

getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stack String?

Available on Error, provided by the Error$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited