contextValue property

String? get contextValue

Context value of the comment. This can be used to contribute comment specific actions. For example, a comment is given a context value as editable. When contributing actions to comments/comment/title using menus extension point, you can specify context value for key comment in when expression like comment == editable.

	"contributes": {
		"menus": {
			"comments/comment/title": [
				{
					"command": "extension.deleteComment",
					"when": "comment == editable"
				}
			]
		}
	}

This will show action extension.deleteComment only for comments with contextValue is editable.

Implementation

_i2.String? get contextValue => _i5.getProperty(
      this,
      'contextValue',
    );
set contextValue (String? value)

Implementation

set contextValue(_i2.String? value) {
  _i5.setProperty(
    this,
    'contextValue',
    value ?? _i6.undefined,
  );
}