CommentAuthorInformation class

Author information of a {@link Comment}

Available extensions
Annotations

Constructors

CommentAuthorInformation({String? name, Uri? iconPath})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
iconPath ↔ Uri?

Available on CommentAuthorInformation, provided by the CommentAuthorInformation$Typings extension

The optional icon path for the author
getter/setter pair
name ↔ String

Available on CommentAuthorInformation, provided by the CommentAuthorInformation$Typings extension

The display name of the author of the comment
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited