DecorationRenderOptions class

Represents rendering styles for a {@link TextEditorDecorationTypetext editor decoration}.

Implemented types
Available extensions
Annotations

Constructors

DecorationRenderOptions({bool? isWholeLine, DecorationRangeBehavior? rangeBehavior, OverviewRulerLane? overviewRulerLane, ThemableDecorationRenderOptions? light, ThemableDecorationRenderOptions? dark, Object? backgroundColor, String? outline, Object? outlineColor, String? outlineStyle, String? outlineWidth, String? border, Object? borderColor, String? borderRadius, String? borderSpacing, String? borderStyle, String? borderWidth, String? fontStyle, String? fontWeight, String? textDecoration, String? cursor, Object? color, String? opacity, String? letterSpacing, Object? gutterIconPath, String? gutterIconSize, Object? overviewRulerColor, ThemableDecorationAttachmentRenderOptions? before, ThemableDecorationAttachmentRenderOptions? after})
factory

Properties

after ↔ ThemableDecorationAttachmentRenderOptions?

Available on ThemableDecorationRenderOptions, provided by the ThemableDecorationRenderOptions$Typings extension

Defines the rendering options of the attachment that is inserted after the decorated text.
getter/setter pair
backgroundColor ↔ Object?

Available on ThemableDecorationRenderOptions, provided by the ThemableDecorationRenderOptions$Typings extension

Background color of the decoration. Use rgba() and define transparent background colors to play well with other decorations. Alternatively a color from the color registry can be {@link ThemeColor referenced}.
getter/setter pair
before ↔ ThemableDecorationAttachmentRenderOptions?

Available on ThemableDecorationRenderOptions, provided by the ThemableDecorationRenderOptions$Typings extension

Defines the rendering options of the attachment that is inserted before the decorated text.
getter/setter pair
border ↔ String?

Available on ThemableDecorationRenderOptions, provided by the ThemableDecorationRenderOptions$Typings extension

CSS styling property that will be applied to text enclosed by a decoration.
getter/setter pair
borderColor ↔ Object?

Available on ThemableDecorationRenderOptions, provided by the ThemableDecorationRenderOptions$Typings extension

CSS styling property that will be applied to text enclosed by a decoration. Better use 'border' for setting one or more of the individual border properties.
getter/setter pair
borderRadius ↔ String?

Available on ThemableDecorationRenderOptions, provided by the ThemableDecorationRenderOptions$Typings extension

CSS styling property that will be applied to text enclosed by a decoration. Better use 'border' for setting one or more of the individual border properties.
getter/setter pair
borderSpacing ↔ String?

Available on ThemableDecorationRenderOptions, provided by the ThemableDecorationRenderOptions$Typings extension

CSS styling property that will be applied to text enclosed by a decoration. Better use 'border' for setting one or more of the individual border properties.
getter/setter pair
borderStyle ↔ String?

Available on ThemableDecorationRenderOptions, provided by the ThemableDecorationRenderOptions$Typings extension

CSS styling property that will be applied to text enclosed by a decoration. Better use 'border' for setting one or more of the individual border properties.
getter/setter pair
borderWidth ↔ String?

Available on ThemableDecorationRenderOptions, provided by the ThemableDecorationRenderOptions$Typings extension

CSS styling property that will be applied to text enclosed by a decoration. Better use 'border' for setting one or more of the individual border properties.
getter/setter pair
color ↔ Object?

Available on ThemableDecorationRenderOptions, provided by the ThemableDecorationRenderOptions$Typings extension

CSS styling property that will be applied to text enclosed by a decoration.
getter/setter pair
cursor ↔ String?

Available on ThemableDecorationRenderOptions, provided by the ThemableDecorationRenderOptions$Typings extension

CSS styling property that will be applied to text enclosed by a decoration.
getter/setter pair
dark ↔ ThemableDecorationRenderOptions?

Available on DecorationRenderOptions, provided by the DecorationRenderOptions$Typings extension

Overwrite options for dark themes.
getter/setter pair
fontStyle ↔ String?

Available on ThemableDecorationRenderOptions, provided by the ThemableDecorationRenderOptions$Typings extension

CSS styling property that will be applied to text enclosed by a decoration.
getter/setter pair
fontWeight ↔ String?

Available on ThemableDecorationRenderOptions, provided by the ThemableDecorationRenderOptions$Typings extension

CSS styling property that will be applied to text enclosed by a decoration.
getter/setter pair
gutterIconPath ↔ Object?

Available on ThemableDecorationRenderOptions, provided by the ThemableDecorationRenderOptions$Typings extension

An absolute path or an URI to an image to be rendered in the gutter.
getter/setter pair
gutterIconSize ↔ String?

Available on ThemableDecorationRenderOptions, provided by the ThemableDecorationRenderOptions$Typings extension

Specifies the size of the gutter icon. Available values are 'auto', 'contain', 'cover' and any percentage value. For further information: https://msdn.microsoft.com/en-us/library/jj127316(v=vs.85).aspx
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isWholeLine ↔ bool?

Available on DecorationRenderOptions, provided by the DecorationRenderOptions$Typings extension

Should the decoration be rendered also on the whitespace after the line text. Defaults to false.
getter/setter pair
letterSpacing ↔ String?

Available on ThemableDecorationRenderOptions, provided by the ThemableDecorationRenderOptions$Typings extension

CSS styling property that will be applied to text enclosed by a decoration.
getter/setter pair
light ↔ ThemableDecorationRenderOptions?

Available on DecorationRenderOptions, provided by the DecorationRenderOptions$Typings extension

Overwrite options for light themes.
getter/setter pair
opacity ↔ String?

Available on ThemableDecorationRenderOptions, provided by the ThemableDecorationRenderOptions$Typings extension

CSS styling property that will be applied to text enclosed by a decoration.
getter/setter pair
outline ↔ String?

Available on ThemableDecorationRenderOptions, provided by the ThemableDecorationRenderOptions$Typings extension

CSS styling property that will be applied to text enclosed by a decoration.
getter/setter pair
outlineColor ↔ Object?

Available on ThemableDecorationRenderOptions, provided by the ThemableDecorationRenderOptions$Typings extension

CSS styling property that will be applied to text enclosed by a decoration. Better use 'outline' for setting one or more of the individual outline properties.
getter/setter pair
outlineStyle ↔ String?

Available on ThemableDecorationRenderOptions, provided by the ThemableDecorationRenderOptions$Typings extension

CSS styling property that will be applied to text enclosed by a decoration. Better use 'outline' for setting one or more of the individual outline properties.
getter/setter pair
outlineWidth ↔ String?

Available on ThemableDecorationRenderOptions, provided by the ThemableDecorationRenderOptions$Typings extension

CSS styling property that will be applied to text enclosed by a decoration. Better use 'outline' for setting one or more of the individual outline properties.
getter/setter pair
overviewRulerColor ↔ Object?

Available on ThemableDecorationRenderOptions, provided by the ThemableDecorationRenderOptions$Typings extension

The color of the decoration in the overview ruler. Use rgba() and define transparent colors to play well with other decorations.
getter/setter pair
overviewRulerLane ↔ OverviewRulerLane?

Available on DecorationRenderOptions, provided by the DecorationRenderOptions$Typings extension

The position in the overview ruler where the decoration should be rendered.
getter/setter pair
rangeBehavior ↔ DecorationRangeBehavior?

Available on DecorationRenderOptions, provided by the DecorationRenderOptions$Typings extension

Customize the growing behavior of the decoration when edits occur at the edges of the decoration's range. Defaults to DecorationRangeBehavior.OpenOpen.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textDecoration ↔ String?

Available on ThemableDecorationRenderOptions, provided by the ThemableDecorationRenderOptions$Typings extension

CSS styling property that will be applied to text enclosed by a decoration.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited