DocumentLink class

A document link is a range in a text document that links to an internal or external resource, like another text document or a web site.

Available extensions
Annotations

Constructors

DocumentLink(Range range, [Uri? target])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
range ↔ Range

Available on DocumentLink, provided by the DocumentLink$Typings extension

The range this link applies to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target ↔ Uri

Available on DocumentLink, provided by the DocumentLink$Typings extension

The uri this link points to.
getter/setter pair
tooltip ↔ String

Available on DocumentLink, provided by the DocumentLink$Typings extension

The tooltip text when you hover over this link.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited