DocumentSymbol class

Represents programming constructs like variables, classes, interfaces etc. that appear in a document. Document symbols can be hierarchical and they have two ranges: one that encloses its definition and one that points to its most interesting range, e.g. the range of an identifier.

Available extensions
Annotations

Constructors

DocumentSymbol(String name, String detail, SymbolKind kind, Range range, Range selectionRange)
factory

Properties

children List<DocumentSymbol>

Available on DocumentSymbol, provided by the DocumentSymbol$Typings extension

Children of this symbol, e.g. properties of a class.
getter/setter pair
detail String

Available on DocumentSymbol, provided by the DocumentSymbol$Typings extension

More detail for this symbol, e.g. the signature of a function.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
kind SymbolKind

Available on DocumentSymbol, provided by the DocumentSymbol$Typings extension

The kind of this symbol.
getter/setter pair
name String

Available on DocumentSymbol, provided by the DocumentSymbol$Typings extension

The name of this symbol.
getter/setter pair
range Range

Available on DocumentSymbol, provided by the DocumentSymbol$Typings extension

The range enclosing this symbol not including leading/trailing whitespace but everything else, e.g. comments and code.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectionRange Range

Available on DocumentSymbol, provided by the DocumentSymbol$Typings extension

The range that should be selected and reveal when this symbol is being picked, e.g. the name of a function. Must be contained by the {@linkcode DocumentSymbol.range range}.
getter/setter pair
tags List<SymbolTag>

Available on DocumentSymbol, provided by the DocumentSymbol$Typings extension

Tags for this symbol.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited