EnvironmentVariableMutator class

A type of mutation and its value to be applied to an environment variable.

Available extensions
Annotations

Properties

hashCode int
The hash code for this object.
no setterinherited
options EnvironmentVariableMutatorOptions

Available on EnvironmentVariableMutator, provided by the EnvironmentVariableMutator$Typings extension

Options applied to the mutator.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type EnvironmentVariableMutatorType

Available on EnvironmentVariableMutator, provided by the EnvironmentVariableMutator$Typings extension

The type of mutation that will occur to the variable.
no setter
value String

Available on EnvironmentVariableMutator, provided by the EnvironmentVariableMutator$Typings extension

The value to use for the variable.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited