Hover class

A hover represents additional information for a symbol or word. Hovers are rendered in a tooltip-like widget.

Available extensions
Annotations

Constructors

Hover(Object contents, [Range? range])
factory

Properties

contents ↔ Array<Object>

Available on Hover, provided by the Hover$Typings extension

The contents of this hover.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
range ↔ Range

Available on Hover, provided by the Hover$Typings extension

The range to which this hover applies. When missing, the editor will use the range at the current position or the current position itself.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited