IInline2 class

Available extensions
Annotations

Constructors

IInline2()

Properties

end ↔ Position?

Available on IInline2, provided by the IInline2$Typings extension

New end position, defaults to {@link Range.end current end}
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start ↔ Position?

Available on IInline2, provided by the IInline2$Typings extension

New start position, defaults to {@link Range.start current start}
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited