InlayHintLabelPart class

An inlay hint label part allows for interactive and composite labels of inlay hints.

Available extensions
Annotations

Constructors

InlayHintLabelPart(String value)
factory

Properties

command Command?

Available on InlayHintLabelPart, provided by the InlayHintLabelPart$Typings extension

An optional command for this label part.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
location Location?

Available on InlayHintLabelPart, provided by the InlayHintLabelPart$Typings extension

An optional {@link Location source code location} that represents this label part.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tooltip ↔ dynamic

Available on InlayHintLabelPart, provided by the InlayHintLabelPart$Typings extension

The tooltip text when you hover over this label part.
getter/setter pair
value String

Available on InlayHintLabelPart, provided by the InlayHintLabelPart$Typings extension

The value of this label part.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited