InlineValueText class

Provide inline value as text.

Available extensions
Annotations

Constructors

InlineValueText(Range range, String text)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
range Range

Available on InlineValueText, provided by the InlineValueText$Typings extension

The document range for which the inline value applies.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String

Available on InlineValueText, provided by the InlineValueText$Typings extension

The text of the inline value.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited