InlineValueVariableLookup class

Provide inline value through a variable lookup. If only a range is specified, the variable name will be extracted from the underlying document. An optional variable name can be used to override the extracted name.

Available extensions
Annotations

Constructors

InlineValueVariableLookup(Range range, [String? variableName, bool? caseSensitiveLookup])
factory

Properties

caseSensitiveLookup bool

Available on InlineValueVariableLookup, provided by the InlineValueVariableLookup$Typings extension

How to perform the lookup.
no setter
hashCode int
The hash code for this object.
no setterinherited
range Range

Available on InlineValueVariableLookup, provided by the InlineValueVariableLookup$Typings extension

The document range for which the inline value applies. The range is used to extract the variable name from the underlying document.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variableName String?

Available on InlineValueVariableLookup, provided by the InlineValueVariableLookup$Typings extension

If specified the name of the variable to look up.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited