Location class

Represents a location inside a resource, such as a line inside a text file.

Available extensions
Annotations

Constructors

Location(Uri uri, Object rangeOrPosition)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
range Range

Available on Location, provided by the Location$Typings extension

The document range of this location.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri Uri

Available on Location, provided by the Location$Typings extension

The resource identifier of this location.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited