NotebookRange class

A notebook range represents an ordered pair of two cell indices. It is guaranteed that start is less than or equal to end.

Available extensions
Annotations

Constructors

NotebookRange(num start, num end)
factory

Properties

end num

Available on NotebookRange, provided by the NotebookRange$Typings extension

The exclusive end index of this range (zero-based).
no setter
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool

Available on NotebookRange, provided by the NotebookRange$Typings extension

true if start and end are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start num

Available on NotebookRange, provided by the NotebookRange$Typings extension

The zero-based start index of this range.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
with$(IInline74 change) NotebookRange

Available on NotebookRange, provided by the NotebookRange$Typings extension

Derive a new range for this range.

Operators

operator ==(Object other) bool
The equality operator.
inherited