OnEnterRule class

Describes a rule to be evaluated when pressing Enter.

Available extensions
Annotations

Constructors

OnEnterRule({RegExp? beforeText, RegExp? afterText, RegExp? previousLineText, EnterAction? action})
factory

Properties

action ↔ EnterAction

Available on OnEnterRule, provided by the OnEnterRule$Typings extension

The action to execute.
getter/setter pair
afterText ↔ RegExp?

Available on OnEnterRule, provided by the OnEnterRule$Typings extension

This rule will only execute if the text after the cursor matches this regular expression.
getter/setter pair
beforeText ↔ RegExp

Available on OnEnterRule, provided by the OnEnterRule$Typings extension

This rule will only execute if the text before the cursor matches this regular expression.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
previousLineText ↔ RegExp?

Available on OnEnterRule, provided by the OnEnterRule$Typings extension

This rule will only execute if the text above the current line matches this regular expression.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited