ParameterInformation class

Represents a parameter of a callable-signature. A parameter can have a label and a doc-comment.

Available extensions
Annotations

Constructors

ParameterInformation(Object label, [Object? documentation])
factory

Properties

documentation ↔ Object

Available on ParameterInformation, provided by the ParameterInformation$Typings extension

The human-readable doc-comment of this signature. Will be shown in the UI but can be omitted.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
label ↔ Object

Available on ParameterInformation, provided by the ParameterInformation$Typings extension

The label of this signature.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited