SaveDialogOptions class

Options to configure the behaviour of a file save dialog.

Available extensions
Annotations

Constructors

SaveDialogOptions({Uri? defaultUri, String? saveLabel, Object? filters, String? title})
factory

Properties

defaultUri ↔ Uri?

Available on SaveDialogOptions, provided by the SaveDialogOptions$Typings extension

The resource the dialog shows when opened.
getter/setter pair
filters ↔ Object?

Available on SaveDialogOptions, provided by the SaveDialogOptions$Typings extension

A set of file filters that are used by the dialog. Each entry is a human-readable label, like "TypeScript", and an array of extensions, e.g.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saveLabel ↔ String?

Available on SaveDialogOptions, provided by the SaveDialogOptions$Typings extension

A human-readable string for the save button.
getter/setter pair
title ↔ String?

Available on SaveDialogOptions, provided by the SaveDialogOptions$Typings extension

Dialog title.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited