SemanticTokensEdits class

Represents edits to semantic tokens.

Available extensions
Annotations

Constructors

SemanticTokensEdits(List<SemanticTokensEdit> edits, [String? resultId])
factory

Properties

edits → List<SemanticTokensEdit>

Available on SemanticTokensEdits, provided by the SemanticTokensEdits$Typings extension

The edits to the tokens data. All edits refer to the initial data state.
no setter
hashCode → int
The hash code for this object.
no setterinherited
resultId → String?

Available on SemanticTokensEdits, provided by the SemanticTokensEdits$Typings extension

The result id of the tokens.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited