SignatureHelpContext class

Additional information about the context in which a {@linkcode SignatureHelpProvider.provideSignatureHelpSignatureHelpProvider} was triggered.

Available extensions
Annotations

Constructors

SignatureHelpContext({SignatureHelpTriggerKind? triggerKind, String? triggerCharacter, bool? isRetrigger, SignatureHelp? activeSignatureHelp})
factory

Properties

activeSignatureHelp → SignatureHelp?

Available on SignatureHelpContext, provided by the SignatureHelpContext$Typings extension

The currently active {@linkcode SignatureHelp}.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isRetrigger → bool

Available on SignatureHelpContext, provided by the SignatureHelpContext$Typings extension

true if signature help was already showing when it was triggered.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
triggerCharacter → String?

Available on SignatureHelpContext, provided by the SignatureHelpContext$Typings extension

Character that caused signature help to be triggered.
no setter
triggerKind → SignatureHelpTriggerKind

Available on SignatureHelpContext, provided by the SignatureHelpContext$Typings extension

Action that caused signature help to be triggered.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited