SourceControlResourceState$Typings extension

on

Properties

command → Command?

Available on SourceControlResourceState, provided by the SourceControlResourceState$Typings extension

The {@link Command} which should be run when the resource state is open in the Source Control viewlet.
no setter
contextValue → String?

Available on SourceControlResourceState, provided by the SourceControlResourceState$Typings extension

Context value of the resource state. This can be used to contribute resource specific actions. For example, if a resource is given a context value as diffable. When contributing actions to scm/resourceState/context using menus extension point, you can specify context value for key scmResourceState in when expressions, like scmResourceState == diffable.
no setter
decorations → SourceControlResourceDecorations?

Available on SourceControlResourceState, provided by the SourceControlResourceState$Typings extension

The {@link SourceControlResourceDecorationsdecorations} for this source control resource state.
no setter
resourceUri → Uri

Available on SourceControlResourceState, provided by the SourceControlResourceState$Typings extension

The {@link Uri} of the underlying resource inside the workspace.
no setter