TabGroup class

Represents a group of tabs. A tab group itself consists of multiple tabs.

Available extensions
Annotations

Constructors

TabGroup({bool? isActive, ViewColumn? viewColumn, Tab? activeTab, List<Tab>? tabs})
factory

Properties

activeTab → Tab?

Available on TabGroup, provided by the TabGroup$Typings extension

The active {@link Tabtab} in the group. This is the tab whose contents are currently being rendered.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isActive → bool

Available on TabGroup, provided by the TabGroup$Typings extension

Whether or not the group is currently active.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tabs → List<Tab>

Available on TabGroup, provided by the TabGroup$Typings extension

The list of tabs contained within the group. This can be empty if the group has no tabs open.
no setter
viewColumn → ViewColumn

Available on TabGroup, provided by the TabGroup$Typings extension

The view column of the group.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited