TabGroups class

Represents the main editor area which consists of multiple groups which contain tabs.

Available extensions
Annotations

Constructors

TabGroups({List<TabGroup>? all, TabGroup? activeTabGroup, Event<TabGroupChangeEvent>? onDidChangeTabGroups, Event<TabChangeEvent>? onDidChangeTabs})
factory

Properties

activeTabGroup → TabGroup

Available on TabGroups, provided by the TabGroups$Typings extension

The currently active group.
no setter
all → List<TabGroup>

Available on TabGroups, provided by the TabGroups$Typings extension

All the groups within the group container.
no setter
close → ({Future Function(Object tab, [bool? preserveFocus]) $1, Future Function(Object tab, [bool? preserveFocus]) $2})

Available on TabGroups, provided by the TabGroups$Typings extension

Overload accessor: $1, $2
no setter
hashCode → int
The hash code for this object.
no setterinherited
onDidChangeTabGroups → Event<TabGroupChangeEvent>

Available on TabGroups, provided by the TabGroups$Typings extension

An {@link Eventevent} which fires when {@link TabGrouptab groups} have changed.
no setter
onDidChangeTabs → Event<TabChangeEvent>

Available on TabGroups, provided by the TabGroups$Typings extension

An {@link Eventevent} which fires when {@link Tabtabs} have changed.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited