TabInputNotebookDiff class

The tabs represents two notebooks in a diff configuration.

Available extensions
Annotations

Constructors

TabInputNotebookDiff(Uri original, Uri modified, String notebookType)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
modified Uri

Available on TabInputNotebookDiff, provided by the TabInputNotebookDiff$Typings extension

The uri of the modified notebook.
no setter
notebookType String

Available on TabInputNotebookDiff, provided by the TabInputNotebookDiff$Typings extension

The type of notebook. Maps to {@linkcode NotebookDocument.notebookTypeNotebookDocuments's notebookType}
no setter
original Uri

Available on TabInputNotebookDiff, provided by the TabInputNotebookDiff$Typings extension

The uri of the original notebook.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited