TaskGroup class

A grouping for tasks. The editor by default supports the 'Clean', 'Build', 'RebuildAll' and 'Test' group.

Available extensions
Annotations

Constructors

TaskGroup(String id, String label)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String

Available on TaskGroup, provided by the TaskGroup$Typings extension

The ID of the task group. Is one of TaskGroup.Clean.id, TaskGroup.Build.id, TaskGroup.Rebuild.id, or TaskGroup.Test.id.
no setter
isDefault bool?

Available on TaskGroup, provided by the TaskGroup$Typings extension

Whether the task that is part of this group is the default for the group. This property cannot be set through API, and is controlled by a user's task configurations.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

build TaskGroup
The build task group;
getter/setter pair
clean TaskGroup
The clean task group;
getter/setter pair
rebuild TaskGroup
The rebuild all task group;
getter/setter pair
test TaskGroup
The test all task group;
getter/setter pair