TaskProcessStartEvent class

An event signaling the start of a process execution triggered through a task

Available extensions
Annotations

Constructors

TaskProcessStartEvent({TaskExecution? execution, num? processId})
factory

Properties

execution → TaskExecution

Available on TaskProcessStartEvent, provided by the TaskProcessStartEvent$Typings extension

The task execution for which the process got started.
no setter
hashCode → int
The hash code for this object.
no setterinherited
processId → num

Available on TaskProcessStartEvent, provided by the TaskProcessStartEvent$Typings extension

The underlying process id.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited