TaskStartEvent class

An event signaling the start of a task execution.

This interface is not intended to be implemented.

Available extensions
Annotations

Constructors

TaskStartEvent({TaskExecution? execution})
factory

Properties

execution → TaskExecution

Available on TaskStartEvent, provided by the TaskStartEvent$Typings extension

The task item representing the task that got started.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited