TelemetryLoggerOptions class

Options for creating a {@link TelemetryLogger}

Available extensions
Annotations

Constructors

TelemetryLoggerOptions({bool? ignoreBuiltInCommonProperties, bool? ignoreUnhandledErrors, dynamic additionalCommonProperties})
factory

Properties

additionalCommonProperties → dynamic

Available on TelemetryLoggerOptions, provided by the TelemetryLoggerOptions$Typings extension

Any additional common properties which should be injected into the data object.
no setter
hashCode → int
The hash code for this object.
no setterinherited
ignoreBuiltInCommonProperties → bool?

Available on TelemetryLoggerOptions, provided by the TelemetryLoggerOptions$Typings extension

Whether or not you want to avoid having the built-in common properties such as os, extension name, etc injected into the data object. Defaults to false if not defined.
no setter
ignoreUnhandledErrors → bool?

Available on TelemetryLoggerOptions, provided by the TelemetryLoggerOptions$Typings extension

Whether or not unhandled errors on the extension host caused by your extension should be logged to your sender. Defaults to false if not defined.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited