TerminalProfile class

A terminal profile defines how a terminal will be launched.

Available extensions
Annotations

Constructors

TerminalProfile(Object options)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
options Object

Available on TerminalProfile, provided by the TerminalProfile$Typings extension

The options that the terminal will launch with.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited