ThemableDecorationInstanceRenderOptions class

Represents themable render options for decoration instances.

Implementers
Available extensions
Annotations

Properties

after ↔ ThemableDecorationAttachmentRenderOptions?

Available on ThemableDecorationInstanceRenderOptions, provided by the ThemableDecorationInstanceRenderOptions$Typings extension

Defines the rendering options of the attachment that is inserted after the decorated text.
getter/setter pair
before ↔ ThemableDecorationAttachmentRenderOptions?

Available on ThemableDecorationInstanceRenderOptions, provided by the ThemableDecorationInstanceRenderOptions$Typings extension

Defines the rendering options of the attachment that is inserted before the decorated text.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited