TypeHierarchyItem class

Represents an item of a type hierarchy, like a class or an interface.

Available extensions
Annotations

Constructors

TypeHierarchyItem(SymbolKind kind, String name, String detail, Uri uri, Range range, Range selectionRange)
factory

Properties

detail String

Available on TypeHierarchyItem, provided by the TypeHierarchyItem$Typings extension

More detail for this item, e.g. the signature of a function.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
kind SymbolKind

Available on TypeHierarchyItem, provided by the TypeHierarchyItem$Typings extension

The kind of this item.
getter/setter pair
name String

Available on TypeHierarchyItem, provided by the TypeHierarchyItem$Typings extension

The name of this item.
getter/setter pair
range Range

Available on TypeHierarchyItem, provided by the TypeHierarchyItem$Typings extension

The range enclosing this symbol not including leading/trailing whitespace but everything else, e.g. comments and code.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectionRange Range

Available on TypeHierarchyItem, provided by the TypeHierarchyItem$Typings extension

The range that should be selected and revealed when this symbol is being picked, e.g. the name of a class. Must be contained by the {@link TypeHierarchyItem.range range}-property.
getter/setter pair
tags ReadonlyArray<SymbolTag>

Available on TypeHierarchyItem, provided by the TypeHierarchyItem$Typings extension

Tags for this item.
getter/setter pair
uri Uri

Available on TypeHierarchyItem, provided by the TypeHierarchyItem$Typings extension

The resource identifier of this item.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited