ViewBadge class

A badge presenting a value for a view

Available extensions
Annotations

Constructors

ViewBadge({String? tooltip, num? value})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tooltip → String

Available on ViewBadge, provided by the ViewBadge$Typings extension

A label to present in tooltip for the badge.
no setter
value → num

Available on ViewBadge, provided by the ViewBadge$Typings extension

The value to present in the badge.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited