WebSocket class

Available extensions
Annotations

Constructors

WebSocket(String path)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
readyState int

Available on WebSocket, provided by the VSWebSocket extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String command, dynamic callback([dynamic data, dynamic foo])) → void

Available on WebSocket, provided by the VSWebSocket extension

send(String buf) → void

Available on WebSocket, provided by the VSWebSocket extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited