WebviewPanel class

A panel that contains a webview.

Available extensions
Annotations

Constructors

WebviewPanel({String? viewType, String? title, Object? iconPath, Webview? webview, WebviewPanelOptions? options, ViewColumn? viewColumn, bool? active, bool? visible, Event<WebviewPanelOnDidChangeViewStateEvent>? onDidChangeViewState, Event<void>? onDidDispose, void reveal([ViewColumn?, bool?])?, dynamic dispose()?})
factory

Properties

active → bool

Available on WebviewPanel, provided by the WebviewPanel$Typings extension

Whether the panel is active (focused by the user).
no setter
dispose ↔ dynamic Function()

Available on WebviewPanel, provided by the WebviewPanel$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iconPath ↔ Object?

Available on WebviewPanel, provided by the WebviewPanel$Typings extension

Icon for the panel shown in UI.
getter/setter pair
onDidChangeViewState → Event<WebviewPanelOnDidChangeViewStateEvent>

Available on WebviewPanel, provided by the WebviewPanel$Typings extension

Fired when the panel's view state changes.
no setter
onDidDispose → Event<void>

Available on WebviewPanel, provided by the WebviewPanel$Typings extension

Fired when the panel is disposed.
no setter
options → WebviewPanelOptions

Available on WebviewPanel, provided by the WebviewPanel$Typings extension

Content settings for the webview panel.
no setter
reveal ↔ void Function([ViewColumn? column, bool? preserveFocus])

Available on WebviewPanel, provided by the WebviewPanel$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String

Available on WebviewPanel, provided by the WebviewPanel$Typings extension

Title of the panel shown in UI.
getter/setter pair
viewColumn → ViewColumn?

Available on WebviewPanel, provided by the WebviewPanel$Typings extension

Editor position of the panel. This property is only set if the webview is in one of the editor view columns.
no setter
viewType → String

Available on WebviewPanel, provided by the WebviewPanel$Typings extension

Identifies the type of the webview panel, such as 'markdown.preview'.
no setter
visible → bool

Available on WebviewPanel, provided by the WebviewPanel$Typings extension

Whether the panel is visible.
no setter
webview → Webview

Available on WebviewPanel, provided by the WebviewPanel$Typings extension

{@linkcode Webview} belonging to the panel.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited