CSSUnparsedValue class

Implemented types
Available extensions
Annotations

Constructors

CSSUnparsedValue(List<Object> members)
factory

Properties

entries ↔ IterableIterator<(num, Object)> Function()

Available on CSSUnparsedValue, provided by the CSSUnparsedValue$Typings extension

getter/setter pair
forEach ↔ void Function(void (Object, num, CSSUnparsedValue), [dynamic])

Available on CSSUnparsedValue, provided by the CSSUnparsedValue$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keys ↔ IterableIterator<num> Function()

Available on CSSUnparsedValue, provided by the CSSUnparsedValue$Typings extension

getter/setter pair
length → num

Available on CSSUnparsedValue, provided by the CSSUnparsedValue$Typings extension

MDN Reference
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toString$ ↔ String Function()

Available on CSSStyleValue, provided by the CSSStyleValue$Typings extension

getter/setter pair
values ↔ IterableIterator<Object> Function()

Available on CSSUnparsedValue, provided by the CSSUnparsedValue$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](num index) → Object

Available on CSSUnparsedValue, provided by the CSSUnparsedValue$Typings extension

operator []=(num index, Object value) → void

Available on CSSUnparsedValue, provided by the CSSUnparsedValue$Typings extension