EXTSRGB class

Available extensions
Annotations

Constructors

EXTSRGB({num? srgbExt, num? srgbAlphaExt, num? srgb8Alpha8Ext, num? framebufferAttachmentColorEncodingExt})
factory

Properties

framebufferAttachmentColorEncodingExt → num

Available on EXTSRGB, provided by the EXTSRGB$Typings extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
srgb8Alpha8Ext → num

Available on EXTSRGB, provided by the EXTSRGB$Typings extension

no setter
srgbAlphaExt → num

Available on EXTSRGB, provided by the EXTSRGB$Typings extension

no setter
srgbExt → num

Available on EXTSRGB, provided by the EXTSRGB$Typings extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

framebufferAttachmentColorEncodingExt → num
no setter
srgb8Alpha8Ext → num
no setter
srgbAlphaExt → num
no setter
srgbExt → num
no setter