FileReaderSync class

Allows to read File or Blob objects in a synchronous way.

MDN Reference

Available extensions
Annotations

Constructors

FileReaderSync()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
readAsArrayBuffer ByteBuffer Function(Blob)

Available on FileReaderSync, provided by the FileReaderSync$Typings extension

getter/setter pair
readAsBinaryString String Function(Blob)

Available on FileReaderSync, provided by the FileReaderSync$Typings extension

getter/setter pair
readAsDataURL String Function(Blob)

Available on FileReaderSync, provided by the FileReaderSync$Typings extension

getter/setter pair
readAsText String Function(Blob, [String?])

Available on FileReaderSync, provided by the FileReaderSync$Typings extension

getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited