IDBFactory class

In the following code snippet, we make a request to open a database, and include handlers for the success and error cases. For a full working example, see our To-do Notifications app (view example live.)

MDN Reference

Available extensions
Annotations

Constructors

IDBFactory()
factory

Properties

cmp ↔ num Function([dynamic, dynamic])

Available on IDBFactory, provided by the IDBFactory$Typings extension

getter/setter pair
databases ↔ Future<List<IDBDatabaseInfo>> Function()

Available on IDBFactory, provided by the IDBFactory$Typings extension

getter/setter pair
deleteDatabase ↔ IDBOpenDBRequest Function(String)

Available on IDBFactory, provided by the IDBFactory$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
open ↔ IDBOpenDBRequest Function(String, [num?])

Available on IDBFactory, provided by the IDBFactory$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited