IDBIndex class

IDBIndex interface of the IndexedDB API provides asynchronous access to an index in a database. An index is a kind of object store for looking up records in another object store, called the referenced object store. You use this interface to retrieve data.

MDN Reference

Available extensions
Annotations

Constructors

IDBIndex()
factory

Properties

count IDBRequest<num> Function([Object?])

Available on IDBIndex, provided by the IDBIndex$Typings extension

getter/setter pair
get IDBRequest Function(Object)

Available on IDBIndex, provided by the IDBIndex$Typings extension

getter/setter pair
getAll IDBRequest<List> Function([dynamic, num?])

Available on IDBIndex, provided by the IDBIndex$Typings extension

getter/setter pair
getAllKeys IDBRequest<List<Object>> Function([dynamic, num?])

Available on IDBIndex, provided by the IDBIndex$Typings extension

getter/setter pair
getKey IDBRequest<Object?> Function(Object)

Available on IDBIndex, provided by the IDBIndex$Typings extension

getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
keyPath Object

Available on IDBIndex, provided by the IDBIndex$Typings extension

MDN Reference
no setter
multiEntry bool

Available on IDBIndex, provided by the IDBIndex$Typings extension

MDN Reference
no setter
name String

Available on IDBIndex, provided by the IDBIndex$Typings extension

Returns the name of the index.
getter/setter pair
objectStore IDBObjectStore

Available on IDBIndex, provided by the IDBIndex$Typings extension

Returns the IDBObjectStore the index belongs to.
no setter
openCursor IDBRequest<IDBCursorWithValue?> Function([dynamic, IDBCursorDirection?])

Available on IDBIndex, provided by the IDBIndex$Typings extension

getter/setter pair
openKeyCursor IDBRequest<IDBCursor?> Function([dynamic, IDBCursorDirection?])

Available on IDBIndex, provided by the IDBIndex$Typings extension

getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unique bool

Available on IDBIndex, provided by the IDBIndex$Typings extension

MDN Reference
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited