Lock class

Available only in secure contexts.

MDN Reference

Available extensions
Annotations

Constructors

Lock()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
mode LockMode

Available on Lock, provided by the Lock$Typings extension

MDN Reference
no setter
name String

Available on Lock, provided by the Lock$Typings extension

MDN Reference
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited