MessageChannel class

This Channel Messaging API interface allows us to create a new message channel and send data through it via its two MessagePort properties.

MDN Reference

Available extensions
Annotations

Constructors

MessageChannel()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
port1 MessagePort

Available on MessageChannel, provided by the MessageChannel$Typings extension

Returns the first MessagePort object.
no setter
port2 MessagePort

Available on MessageChannel, provided by the MessageChannel$Typings extension

Returns the second MessagePort object.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited