NavigatorLocks class

Available only in secure contexts.

Implementers
Available extensions
Annotations

Constructors

factory

Properties

hashCode int
The hash code for this object.
no setterinherited
locks LockManager

Available on NavigatorLocks, provided by the NavigatorLocks$Typings extension

MDN Reference
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited