OVRMultiview2 class

Available extensions
Annotations

Constructors

OVRMultiview2({num? framebufferAttachmentTextureNumViewsOvr, num? framebufferAttachmentTextureBaseViewIndexOvr, num? maxViewsOvr, num? framebufferIncompleteViewTargetsOvr, void framebufferTextureMultiviewOVR(num, num, num, num, num, [WebGLTexture?])?})
factory

Properties

framebufferAttachmentTextureBaseViewIndexOvr → num

Available on OVRMultiview2, provided by the OVRMultiview2$Typings extension

no setter
framebufferAttachmentTextureNumViewsOvr → num

Available on OVRMultiview2, provided by the OVRMultiview2$Typings extension

no setter
framebufferIncompleteViewTargetsOvr → num

Available on OVRMultiview2, provided by the OVRMultiview2$Typings extension

no setter
framebufferTextureMultiviewOVR ↔ void Function(num, num, num, num, num, [WebGLTexture?])

Available on OVRMultiview2, provided by the OVRMultiview2$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxViewsOvr → num

Available on OVRMultiview2, provided by the OVRMultiview2$Typings extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited