WebTransportBidirectionalStream class

Available only in secure contexts.

MDN Reference

Available extensions
Annotations

Constructors

WebTransportBidirectionalStream()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
readable ReadableStream

Available on WebTransportBidirectionalStream, provided by the WebTransportBidirectionalStream$Typings extension

MDN Reference
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
writable WritableStream

Available on WebTransportBidirectionalStream, provided by the WebTransportBidirectionalStream$Typings extension

MDN Reference
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited