WebSocket class

Available extensions
Annotations

Constructors

WebSocket(String url)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
readyState WebSocketReadyState

Available on WebSocket, provided by the TypingsChildProcess extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() → void

Available on WebSocket, provided by the TypingsChildProcess extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, dynamic callback([dynamic, dynamic])) → void

Available on WebSocket, provided by the TypingsChildProcess extension

send(dynamic data) → void

Available on WebSocket, provided by the TypingsChildProcess extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited