WebGLActiveInfo class

Part of the WebGL API and represents the information returned by calling the WebGLRenderingContext.getActiveAttrib() and WebGLRenderingContext.getActiveUniform() methods.

MDN Reference

Available extensions
Annotations

Constructors

WebGLActiveInfo()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String

Available on WebGLActiveInfo, provided by the WebGLActiveInfo$Typings extension

MDN Reference
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size num

Available on WebGLActiveInfo, provided by the WebGLActiveInfo$Typings extension

MDN Reference
no setter
type num

Available on WebGLActiveInfo, provided by the WebGLActiveInfo$Typings extension

MDN Reference
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited